@@ -4,15 +4,23 @@ pub struct Config {
     pub port: u16,
     pub config_path: String,
     pub token: String,
+    pub protocol: String,
 }
 
 impl Config {
-    pub fn new(address: String, port: u16, config_path: String, token: String) -> Self {
+    pub fn new(
+        protocol: String,
+        address: String,
+        port: u16,
+        config_path: String,
+        token: String,
+    ) -> Self {
         Self {
             address,
             port,
             config_path,
             token,
+            protocol,
         }
     }
 }
