@@ -3,6 +3,7 @@ use thiserror::Error;
 
 /// # HTTP response that maybe happen in Vault
 /// - 200	Active Node
+/// - 404   Invalid Path
 /// - 429	Standby Node
 /// - 472	Active DR Secondary Node
 /// - 473	Standby Performance Node
@@ -22,6 +23,8 @@ pub enum VaultError {
     VaultActiveDRsecondaryNode(StatusCode),
     #[error("Vault is in active standby performance node, connection to vault failed | status code: {0}")]
     VaultStandbyPerformanceNode(StatusCode),
+    #[error("Your request is going to invalid path | status code: {0}")]
+    VaultInvalidPath(StatusCode),
     #[error("Vault error unknown, connection to vault failed | status code: {0}")]
     Unknown(StatusCode),
 }
